@@ -1,5 +1,6 @@
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
+import ipdb
 from ..core.version import get_version
 from pprint import pprint as pp
 import os
@@ -53,6 +54,10 @@ class Base(Controller):
             (['-p','--profile'],{
                 "help" : "Which AWS profile should boto3 use",
                 "action" : "store"
+            }),
+            (['-P','--ports'],{
+                "help" : "Which ports should AWS SG set",
+                "action" : "store"
             })
         ]
     )
@@ -60,16 +65,66 @@ class Base(Controller):
         from ..ext.aws_sg import get_sg, update_sg_to_ip
         profile = self.app.pargs.__dict__.get('profile') or self.app.pargs.__dict__.get('p') or 'default'
         name = self.app.pargs.__dict__.get('name') or self.app.pargs.__dict__.get('n') or 'default'
+        
+        # which ports to change
+        ports = self.app.pargs.__dict__.get('ports') or self.app.pargs.__dict__.get('P')
+        if ports: ports = [ int(p) for p in ports.split(',') ]
+        else: ports = [22, 8888, 8501, 8889, 5432]
+        if not isinstance(ports, list): ports = [ports]
+
 
         if self.app.pargs.action=='show':
             pp(get_sg(name, profile))
 
         elif self.app.pargs.action=='update':
-            update_sg_to_ip(sg_name=self.app.pargs.name, profile=profile)
+            update_sg_to_ip(sg_name=self.app.pargs.name, profile=profile, ports=ports)
 
         else:
             raise NotImplementedError('As action, chose one of {update, show}')
 
+    @ex(
+        help="GCP VM Instances helper commands.",
+        arguments=[
+            (['action'],{
+                    "help" : "To show one of {ls, scp}.",
+                    "action" : "store"
+                }),
+            (['--rpath'],{
+                "help" : "What is the location on the remote server",
+                "action": "store"
+            }),
+            (['-f','--filter'],{
+                "help" : "One of {live, all}. Default: live",
+                "action": "store"
+            }),
+            (['-id'],{
+                "help": "InstanceId to be passed to ec2 start/stop",
+                "action": "store"
+            })
+        ]
+    )
+    def gcp(self):
+        from ..ext.gcp import gcp_ls, scp
+
+        # profile = self.app.pargs.profile or 'default'
+        # filt = self.app.pargs.filter or "live"
+
+        if self.app.pargs.action=='ls':
+            print(gcp_ls())
+
+        # elif self.app.pargs.action=='update':
+        #     print(update_ec2_ssh(profile))
+
+        # elif self.app.pargs.action=='start':
+        #     start_ec2(self.app.pargs.id, profile)
+
+        elif self.app.pargs.action=='scp':
+            scp(int(self.app.pargs.id), self.app.pargs.rpath)
+            # stop_ec2(self.app.pargs.id, profile)
+
+        else:
+            raise NotImplementedError("Choose one of {ls, update, start, stop}")
+
     @ex(
         help="AWS EC2 helper commands.",
         arguments=[
@@ -196,6 +251,8 @@ class Base(Controller):
         ]
     )
     def load(self):
+        # TODO: reload the file after.
+        # TODO: load git aliases
         zshrc = os.path.abspath(__file__).split('/')[:-2] + ['ext', 'zshrc.txt']
         tmux = os.path.abspath(__file__).split('/')[:-2] + ['ext', 'tmux.conf']
 
@@ -210,6 +267,7 @@ class Base(Controller):
         else:
             raise NotImplementedError("Try one of {sh, zsh, tmux}")
 
+
     @ex(
         help='Operations on CLI hist',
         arguments=[
