@@ -49,15 +49,21 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         print('No permissions to revoke. Skipping.')
         sg_res.revoke_ingress(IpPermissions=permissions_to_revoke)
 
-    # TODO: align with ports
-    descriptions = [ 'Jakub Aux SSH','Jakub Aux Jupyter', 'Jakub Aux Streamlit', 'Jakub Aux Jupyter2', 'Jakub Aux Postgres']
+    descriptions = {
+        22: 'Jakub Aux SSH',
+        8888: 'Jakub Aux Jupyter',
+        8501: 'Jakub Aux Streamlit',
+        8889: 'Jakub Aux Jupyter2',
+        5432: 'Jakub Aux Postgres'
+    }
+    
 
     ip_perms = [ {
         'IpProtocol': 'tcp',
         'FromPort': ports[i],
         'ToPort': ports[i],
-        'IpRanges': [{'CidrIp': ip, 'Description': descriptions[i]}]
-    } for i in range(len(descriptions)) ]
+        'IpRanges': [{'CidrIp': ip, 'Description': descriptions[ports[i]] }]}
+            for i in range(len(ports)) ]
 
     # print(ip_perms)
 
